@@ -7,14 +7,12 @@
 typedef struct _client {
     int fd;
     char *remote_addr;
-    uint32_t remote_port;
-    
-    uint8_t http_major;
-    uint8_t http_minor;
+    int remote_port;
 
     uint8_t keep_alive;
     request *req;
-    uint32_t body_length;
+    request_queue *request_queue;
+    int body_length;
     int body_readed;
     void *body;
     int bad_request_code;
@@ -31,9 +29,10 @@ typedef struct _client {
     uint8_t header_done;            // header write status
     PyObject *response;         // wsgi response object 
     PyObject *response_iter;    // wsgi response object (iter)
+    uint8_t chunked_response;     // use Transfer-Encoding: chunked
     uint8_t content_length_set;     // content_length_set flag
-    uint32_t content_length;         // content_length
-    uint32_t write_bytes;            // send body length
+    int content_length;         // content_length
+    int write_bytes;            // send body length
     void *bucket;               //write_data
     uint8_t response_closed;    //response closed flag
     uint8_t use_cork;     // use TCP_CORK
